@@ -1,8 +1,9 @@
 import cntk as C
 import cntkx as Cx
 import numpy as np
-from cntk.layers import LayerNormalization, ResNetBlock
+from cntk.layers import ResNetBlock
 from cntkx.layers import PreTrainedBertEmbeddings, PositionwiseFeedForward, Dense, PretrainedBertPooler, Recurrence
+from cntkx.layers import LayerNormalization
 from cntk.default_options import default_override_or
 from cntk.layers.blocks import _inject_name
 
@@ -454,7 +455,7 @@ def GaussianWindowAttention(nb_mixtures, activation=C.softplus, init=C.he_normal
     Note:
         There is a slight deviation from the original implementation where we use softplus as the activation
         function instead of exp. Exp activation causes some minor instability.
-
+    
     Example:
         seq1 = C.Axis.new_unique_dynamic_axis('seq1')
         seq2 = C.Axis.new_unique_dynamic_axis('seq2')
